@@ -45,17 +45,17 @@ var searchData=
   ['tds_5fclose_5fsocket_42',['tds_close_socket',['../a00594.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c'],['../a00594.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c']]],
   ['tds_5fconfig_5fverstr_43',['tds_config_verstr',['../a00589.html#ga05c73c963f4d8904869c739c556c58a2',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c'],['../a00589.html#ga05c73c963f4d8904869c739c556c58a2',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c']]],
   ['tds_5fconvert_44',['tds_convert',['../a00590.html#gad83c146aa5ba3f1515557d6b5248494a',1,'tds_convert(const TDSCONTEXT *tds_ctx, int srctype, const void *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c'],['../a00590.html#gad83c146aa5ba3f1515557d6b5248494a',1,'tds_convert(const TDSCONTEXT *context, int srctype, const void *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c']]],
-  ['tds_5fconvert_5fstream_45',['tds_convert_stream',['../a01494.html#a9d8eb43a81ff58ab423dce0ce95b9564',1,'stream.c']]],
+  ['tds_5fconvert_5fstream_45',['tds_convert_stream',['../a01490.html#a9d8eb43a81ff58ab423dce0ce95b9564',1,'stream.c']]],
   ['tds_5fconvert_5fstring_46',['tds_convert_string',['../a00593.html#ga451c03a088d468a32c1cff9848dd2a6a',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, ptrdiff_t len, size_t *out_len):&#160;query.c'],['../a00593.html#ga451c03a088d468a32c1cff9848dd2a6a',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, ptrdiff_t len, size_t *out_len):&#160;query.c']]],
-  ['tds_5fcopy_5fstream_47',['tds_copy_stream',['../a01494.html#a50bc3749988d1c3c441044fc07ab44e4',1,'stream.c']]],
+  ['tds_5fcopy_5fstream_47',['tds_copy_stream',['../a01490.html#a50bc3749988d1c3c441044fc07ab44e4',1,'stream.c']]],
   ['tds_5fcount_5fplaceholders_48',['tds_count_placeholders',['../a00593.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c'],['../a00593.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c']]],
   ['tds_5fcount_5fplaceholders_5fucs2le_49',['tds_count_placeholders_ucs2le',['../a00593.html#ga0cd19215e9169ea299a6c9cbf5b2fb60',1,'query.c']]],
   ['tds_5fcursor_5fcheck_5fallocated_50',['tds_cursor_check_allocated',['../a00593.html#ga2a64baaf4aa50ef601a49b801dfdaaf6',1,'query.c']]],
   ['tds_5fcursor_5fdealloc_51',['tds_cursor_dealloc',['../a00593.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c'],['../a00593.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c']]],
-  ['tds_5fdatain_5fstream_5finit_52',['tds_datain_stream_init',['../a01494.html#abc3a77c8aa28842e7f28583cbabc1415',1,'stream.c']]],
-  ['tds_5fdatain_5fstream_5fread_53',['tds_datain_stream_read',['../a01494.html#a04b537d889f7d4c9b9701eb81baf7efd',1,'stream.c']]],
-  ['tds_5fdataout_5fstream_5finit_54',['tds_dataout_stream_init',['../a01494.html#aa038a9125979f8f0915dbd53cbf27e5a',1,'stream.c']]],
-  ['tds_5fdataout_5fstream_5fwrite_55',['tds_dataout_stream_write',['../a01494.html#ae38a590ee08cf398e7adef536ac94538',1,'stream.c']]],
+  ['tds_5fdatain_5fstream_5finit_52',['tds_datain_stream_init',['../a01490.html#abc3a77c8aa28842e7f28583cbabc1415',1,'stream.c']]],
+  ['tds_5fdatain_5fstream_5fread_53',['tds_datain_stream_read',['../a01490.html#a04b537d889f7d4c9b9701eb81baf7efd',1,'stream.c']]],
+  ['tds_5fdataout_5fstream_5finit_54',['tds_dataout_stream_init',['../a01490.html#aa038a9125979f8f0915dbd53cbf27e5a',1,'stream.c']]],
+  ['tds_5fdataout_5fstream_5fwrite_55',['tds_dataout_stream_write',['../a01490.html#ae38a590ee08cf398e7adef536ac94538',1,'stream.c']]],
   ['tds_5fdatecrack_56',['tds_datecrack',['../a00590.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c'],['../a00590.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c']]],
   ['tds_5fdeferred_5fcursor_5fdealloc_57',['tds_deferred_cursor_dealloc',['../a00593.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c'],['../a00593.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c']]],
   ['tds_5fdeferred_5funprepare_58',['tds_deferred_unprepare',['../a00593.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
@@ -74,8 +74,8 @@ var searchData=
   ['tds_5fdstr_5fset_71',['tds_dstr_set',['../a00596.html#gab78cc59b110df2817b00f9bed74c6ff1',1,'tdsstring.c']]],
   ['tds_5fdstr_5fsetlen_72',['tds_dstr_setlen',['../a00596.html#ga0cd7863ba7c2d2da4a193234472a3d14',1,'tdsstring.c']]],
   ['tds_5fdstr_5fzero_73',['tds_dstr_zero',['../a00596.html#ga339ba30216e2bd5bd076aa9dcd26f3c4',1,'tdsstring.c']]],
-  ['tds_5fdynamic_5fstream_5finit_74',['tds_dynamic_stream_init',['../a01494.html#a4f9e40da6941cb9407d0da5bc3030517',1,'stream.c']]],
-  ['tds_5fdynamic_5fstream_5fwrite_75',['tds_dynamic_stream_write',['../a01494.html#abaf688c85ea04a2392103d519a55d04e',1,'stream.c']]],
+  ['tds_5fdynamic_5fstream_5finit_74',['tds_dynamic_stream_init',['../a01490.html#a4f9e40da6941cb9407d0da5bc3030517',1,'stream.c']]],
+  ['tds_5fdynamic_5fstream_5fwrite_75',['tds_dynamic_stream_write',['../a01490.html#abaf688c85ea04a2392103d519a55d04e',1,'stream.c']]],
   ['tds_5ffile_5fstream_5fread_76',['tds_file_stream_read',['../a00254.html#a1b83c9db016b481aa1fa0352f976d50d',1,'bulk.c']]],
   ['tds_5ffix_5fcolumn_5fsize_77',['tds_fix_column_size',['../a00593.html#ga79e31bdb1d8e8e214ea2bed964ff0e77',1,'query.c']]],
   ['tds_5ffix_5flogin_78',['tds_fix_login',['../a00589.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c'],['../a00589.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c']]],
@@ -90,7 +90,7 @@ var searchData=
   ['tds_5ffreeze_5fclose_5fstring_87',['tds_freeze_close_string',['../a00594.html#ga084fa9cda46be8594997fed2487fcb50',1,'tds_freeze_close_string(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga084fa9cda46be8594997fed2487fcb50',1,'tds_freeze_close_string(TDSFREEZE *freeze):&#160;packet.c']]],
   ['tds_5ffreeze_5fwritten_88',['tds_freeze_written',['../a00594.html#ga1daa50429a3a5b045ee503581e859a8b',1,'tds_freeze_written(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga1daa50429a3a5b045ee503581e859a8b',1,'tds_freeze_written(TDSFREEZE *freeze):&#160;packet.c']]],
   ['tds_5fgeneric_5fget_89',['tds_generic_get',['../a00263.html#abac4d689e0e31e80587f89247c6395a4',1,'data.c']]],
-  ['tds_5fgeneric_5fput_90',['tds_generic_put',['../a00263.html#a84e17808683ba2dd956e811a42e23176',1,'data.c']]],
+  ['tds_5fgeneric_5fput_90',['tds_generic_put',['../a00263.html#a62c28ebed70681c7a231fae487e2953e',1,'data.c']]],
   ['tds_5fgeneric_5fput_5finfo_91',['tds_generic_put_info',['../a00263.html#aabd0e5f15615b5c141c525b76e746520',1,'data.c']]],
   ['tds_5fget_5fbyte_92',['tds_get_byte',['../a00594.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c']]],
   ['tds_5fget_5fchar_5fdata_93',['tds_get_char_data',['../a00594.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *row_buffer, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c'],['../a00594.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *dest, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c']]],
@@ -112,11 +112,11 @@ var searchData=
   ['tds_5fgoodread_109',['tds_goodread',['../a00594.html#gaa1466c5305333503d6fae82dc271256a',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, size_t buflen):&#160;net.c'],['../a00594.html#gaa1466c5305333503d6fae82dc271256a',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, size_t buflen):&#160;net.c']]],
   ['tds_5fgoodwrite_110',['tds_goodwrite',['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c'],['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c']]],
   ['tds_5ficonv_111',['tds_iconv',['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
-  ['tds_5ficonv_5falloc_112',['tds_iconv_alloc',['../a01506.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00431.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
+  ['tds_5ficonv_5falloc_112',['tds_iconv_alloc',['../a01502.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00431.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
   ['tds_5ficonv_5ffrom_5fcollate_113',['tds_iconv_from_collate',['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c']]],
   ['tds_5ficonv_5fget_5finfo_114',['tds_iconv_get_info',['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c'],['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c']]],
   ['tds_5ficonv_5finfo_5finit_115',['tds_iconv_info_init',['../a00591.html#ga372010075a93be5ea4de15ab63f97cdb',1,'iconv.c']]],
-  ['tds_5ficonv_5finit_116',['tds_iconv_init',['../a01506.html#a30bcae80553efae075b0886bfcda1e35',1,'iconv.c']]],
+  ['tds_5ficonv_5finit_116',['tds_iconv_init',['../a01502.html#a30bcae80553efae075b0886bfcda1e35',1,'iconv.c']]],
   ['tds_5finit_5flogin_117',['tds_init_login',['../a00592.html#ga4f7b22f681e7160ac03dfe8d2ae8bd39',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c'],['../a00592.html#ga4f7b22f681e7160ac03dfe8d2ae8bd39',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c']]],
   ['tds_5flookup_5fdynamic_118',['tds_lookup_dynamic',['../a00595.html#ga4a45cadd06ae1b886459dcc1f8e482c6',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c'],['../a00595.html#ga4a45cadd06ae1b886459dcc1f8e482c6',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c']]],
   ['tds_5flookup_5fhost_119',['tds_lookup_host',['../a00589.html#ga3945f760ceb97e8854e18589d6f0d241',1,'tds_lookup_host(const char *servername):&#160;config.c'],['../a00589.html#ga3945f760ceb97e8854e18589d6f0d241',1,'tds_lookup_host(const char *servername):&#160;config.c']]],
@@ -179,7 +179,7 @@ var searchData=
   ['tds_5fset_5fcolumn_5ftype_176',['tds_set_column_type',['../a00431.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00263.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
   ['tds_5fset_5fcur_5fcursor_177',['tds_set_cur_cursor',['../a00593.html#ga34fb1084682cc31fe02a4a7946955a5a',1,'query.c']]],
   ['tds_5fset_5fcur_5fdyn_178',['tds_set_cur_dyn',['../a00593.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
-  ['tds_5fset_5ficonv_5fname_179',['tds_set_iconv_name',['../a01506.html#a585ebac61354ce540d28f6da2d771b5b',1,'iconv.c']]],
+  ['tds_5fset_5ficonv_5fname_179',['tds_set_iconv_name',['../a01502.html#a585ebac61354ce540d28f6da2d771b5b',1,'iconv.c']]],
   ['tds_5fset_5finterfaces_5ffile_5floc_180',['tds_set_interfaces_file_loc',['../a00589.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interf):&#160;config.c'],['../a00589.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interfloc):&#160;config.c']]],
   ['tds_5fset_5fparam_5ftype_181',['tds_set_param_type',['../a00263.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00431.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
   ['tds_5fset_5fserver_182',['tds_set_server',['../a00431.html#a3ab8874994a0776acdaff797afdb710a',1,'login.c']]],
@@ -195,10 +195,10 @@ var searchData=
   ['tds_5fsocket_5fwrite_192',['tds_socket_write',['../a00594.html#ga9b377b1cd287fd20db54bbca02a954b9',1,'net.c']]],
   ['tds_5fstart_5fquery_193',['tds_start_query',['../a00593.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c'],['../a00593.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c']]],
   ['tds_5fstart_5fquery_5fhead_194',['tds_start_query_head',['../a00593.html#ga9ad2e6defce530a8778791cce0166ccd',1,'query.c']]],
-  ['tds_5fstaticin_5fstream_5finit_195',['tds_staticin_stream_init',['../a01494.html#aa9e1e45f0305622dd6aed9f8fe158581',1,'stream.c']]],
-  ['tds_5fstaticin_5fstream_5fread_196',['tds_staticin_stream_read',['../a01494.html#a76b02f1fa5b79dc7e1ef2651a9afe3f7',1,'stream.c']]],
-  ['tds_5fstaticout_5fstream_5finit_197',['tds_staticout_stream_init',['../a01494.html#a9fe0d3799d2e3bde49b614c9d0c3785d',1,'stream.c']]],
-  ['tds_5fstaticout_5fstream_5fwrite_198',['tds_staticout_stream_write',['../a01494.html#a1d92ebe06f18378ac17ccfd20db05126',1,'stream.c']]],
+  ['tds_5fstaticin_5fstream_5finit_195',['tds_staticin_stream_init',['../a01490.html#aa9e1e45f0305622dd6aed9f8fe158581',1,'stream.c']]],
+  ['tds_5fstaticin_5fstream_5fread_196',['tds_staticin_stream_read',['../a01490.html#a76b02f1fa5b79dc7e1ef2651a9afe3f7',1,'stream.c']]],
+  ['tds_5fstaticout_5fstream_5finit_197',['tds_staticout_stream_init',['../a01490.html#a9fe0d3799d2e3bde49b614c9d0c3785d',1,'stream.c']]],
+  ['tds_5fstaticout_5fstream_5fwrite_198',['tds_staticout_stream_write',['../a01490.html#a1d92ebe06f18378ac17ccfd20db05126',1,'stream.c']]],
   ['tds_5fstrftime_199',['tds_strftime',['../a00590.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *dr, int prec):&#160;convert.c'],['../a00590.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *timeptr, int prec):&#160;convert.c']]],
   ['tds_5fsubmit_5fbegin_5ftran_200',['tds_submit_begin_tran',['../a00593.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c'],['../a00593.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c']]],
   ['tds_5fsubmit_5fcommit_201',['tds_submit_commit',['../a00593.html#ga7d68588fdd0beeae52197a6d6cef8754',1,'tds_submit_commit(TDSSOCKET *tds, bool cont):&#160;query.c'],['../a00593.html#ga7d68588fdd0beeae52197a6d6cef8754',1,'tds_submit_commit(TDSSOCKET *tds, bool cont):&#160;query.c']]],
@@ -223,8 +223,8 @@ var searchData=
   ['tdsdbopen_220',['tdsdbopen',['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
   ['tdsdump_5fclose_221',['tdsdump_close',['../a00431.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
   ['tdsdump_5fcol_222',['tdsdump_col',['../a00431.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
-  ['tdsdump_5fdump_5fbuf_223',['tdsdump_dump_buf',['../a00431.html#a79449d2f35a8acc8ed0585044f75524d',1,'log.c']]],
-  ['tdsdump_5flog_224',['tdsdump_log',['../a00431.html#ab45c291105027e69836002e1dd586141',1,'log.c']]],
+  ['tdsdump_5fdump_5fbuf_5fimpl_223',['tdsdump_dump_buf_impl',['../a00431.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
+  ['tdsdump_5flog_5fimpl_224',['tdsdump_log_impl',['../a00431.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
   ['tdsdump_5foff_225',['tdsdump_off',['../a00431.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
   ['tdsdump_5fon_226',['tdsdump_on',['../a00431.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
   ['tdsdump_5fopen_227',['tdsdump_open',['../a00431.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
